@@ -1,13 +1,12 @@
-import copy
-import warnings
-import xml.etree.ElementTree as ETree
-from abc import ABC, abstractmethod
-
-import numpy as np
-
-from EEETools import costants
 from EEETools.Tools.Other.matrix_analyzer import MatrixAnalyzer
 from EEETools.Tools.modules_handler import ModulesHandler
+import xml.etree.ElementTree as ETree
+from abc import ABC, abstractmethod
+from EEETools import costants
+from typing import Union
+import numpy as np
+import warnings
+import copy
 
 
 class Block(ABC):
@@ -108,7 +107,7 @@ class Block(ABC):
 
     def __get_standard_matrix_row(self, n_blocks):
 
-        # These Methods returns the row of the Cost Matrix corresponding to the current block in a block-oriented
+        # This method return the row of the Cost Matrix corresponding to the current block in a block-oriented
         # computation scheme
 
         # The Cost Matrix is a squared matrix of size NXN where N is the number of blocks. Another column,
@@ -119,7 +118,7 @@ class Block(ABC):
         # into the component from block with ID "m".
 
         # The last column represent known variable and should be filled with the known costs
-        # For further details please refers to the paper (to be quoted)
+        # For further details please refer to the paper (to be quoted)
 
         # line initialization with an array of zeroes (dimension N+1)
         row = np.zeros(n_blocks + 1)
@@ -135,7 +134,7 @@ class Block(ABC):
 
             if not (conn.is_system_input or conn.exergy_value == 0):
 
-                row[conn.fromID] = -conn.exergy_value
+                row[conn.fromID] -= conn.exergy_value
 
             else:
 
@@ -149,6 +148,7 @@ class Block(ABC):
         for conn in self.output_connections:
 
             if not conn.is_loss or (not self.main_class.options.loss_cost_is_zero):
+
                 exergy_sum += conn.exergy_value
 
         row[self.ID] = exergy_sum
@@ -157,7 +157,7 @@ class Block(ABC):
 
     def __get_dissipative_matrix_row(self, n_blocks):
 
-        # These Methods return the rows of the Cost Matrix corresponding to a dissipative block
+        # This method return the rows of the Cost Matrix corresponding to a dissipative block
 
         # The Cost Matrix is a squared matrix of size NXN where N is the number of blocks. Another column,
         # representing the known variables vector has been added at the end of the matrix, hence its actual
@@ -169,7 +169,7 @@ class Block(ABC):
         # exergy flux coming into the component from block with ID "m".
 
         # The last column represent known variable and should be filled with the known costs
-        # For further details please refers to the paper (to be quoted)
+        # For further details please refer to the paper (to be quoted)
 
         # line initialization with an array of zeroes (dimension N+1)
         row = np.zeros(n_blocks + 1)
@@ -184,7 +184,7 @@ class Block(ABC):
 
             if not (conn.is_system_input or conn.exergy_value == 0):
 
-                row[conn.fromID] = -conn.exergy_value
+                row[conn.fromID] -= conn.exergy_value
 
             else:
 
@@ -284,12 +284,17 @@ class Block(ABC):
         c_fuel = 0
         c_dest = 0
 
+        self.calculate_exergy_analysis()
         fuel_exergy = self.exergy_analysis["fuel"]
         dest_exergy = self.exergy_analysis["distruction"]
         dest_loss_exergy = self.exergy_analysis["distruction"] + self.exergy_analysis["losses"]
 
         fuel_cost = 0.
 
+        if self.can_be_removed_in_pf_definition and self.main_class.options.calculate_on_pf_diagram:
+
+            self.output_cost = self.output_connections[0].rel_cost
+
         if self.is_dissipative:
 
             c_prod = self.dissipative_output_cost
@@ -314,11 +319,11 @@ class Block(ABC):
 
         if not c_fuel == 0:
 
-            r = (self.output_cost - c_fuel) / c_fuel
+            r = (c_prod - c_fuel) / c_fuel
 
         if not (self.comp_cost + c_dest * abs(dest_loss_exergy)) == 0:
 
-            f = self.comp_cost / (self.comp_cost + c_dest * abs(dest_loss_exergy))
+            f = self.comp_cost / (self.comp_cost + c_dest * abs(dest_exergy))
 
         if not total_destruction == 0:
 
@@ -525,8 +530,6 @@ class Block(ABC):
 
             sel_block.add_connection(new_connection, is_input)
 
-        self.calculate_exergy_analysis()
-
     def remove_connection(self, deleted_conn):
 
         # This method tries to remove the connection from the input_connections List (it can do that because
@@ -715,6 +718,20 @@ class Block(ABC):
 
         raise (NotImplementedError, "block.__append_xml_connection_list() must be overloaded in subclasses")
 
+
+    # -------------------------------------
+    # ----------- JSON Methods ------------
+    # -------------------------------------
+
+    @classmethod
+    @abstractmethod
+    def get_json_component_description(cls) -> dict:
+        return dict()
+
+    # @abstractmethod
+    def append_json_connection(self, input_conns: dict, output_conns: dict):
+        pass
+
     # -------------------------------------
     # ---------- Support Methods ----------
     # -------------------------------------
@@ -1366,6 +1383,8 @@ class ArrayHandler:
                 self.pf_diagram = PFArrayHandler(self)
                 self.pf_diagram.calculate()
 
+                self.calculate_coefficients()
+
             else:
 
                 i = 0
@@ -1385,10 +1404,10 @@ class ArrayHandler:
                         red_sum = block.redistribution_sum
                         exergy_dissipated = block.exergy_input
 
-                        for non_dissipative_blocks in block.redistribution_block_list:
-
-                            red_perc = non_dissipative_blocks.redistribution_index / red_sum
-                            self.matrix[non_dissipative_blocks.ID, i] -= exergy_dissipated * red_perc
+                        if not red_sum == 0:
+                            for non_dissipative_blocks in block.redistribution_block_list:
+                                red_perc = non_dissipative_blocks.redistribution_index / red_sum
+                                self.matrix[non_dissipative_blocks.ID, i] -= exergy_dissipated * red_perc
 
                     i += 1
 
@@ -1420,6 +1439,12 @@ class ArrayHandler:
 
             block.calculate_coefficients(total_destruction)
 
+    def calculate_exergy_analysis(self):
+
+        for block in self.block_list:
+
+            block.calculate_exergy_analysis()
+
     def decompose_component_output_cost(self):
 
         if self.options.calculate_component_decomposition:
@@ -1451,6 +1476,7 @@ class ArrayHandler:
         # this method has to be called just before the calculation, it asks the blocks to prepare themselves for the
         # calculation
 
+        self.calculate_exergy_analysis()
         self.__update_block_list()
 
         for block in self.block_list:
@@ -1518,7 +1544,7 @@ class ArrayHandler:
     # ----- Elements Handling Methods -----
     # -------------------------------------
 
-    def append_block(self, input_element="Generic"):
+    def append_block(self, input_element="Generic") -> Union[Block, list[Block]]:
 
         # this method accepts three types of inputs:
         #
@@ -1573,12 +1599,14 @@ class ArrayHandler:
     def append_connection(self, new_conn=None, from_block=None, to_block=None) -> Connection:
 
         if new_conn is None:
-            new_conn = Connection(self.n_connection)
+
+            new_conn = Connection(self.__get_empty_index())
 
         self.__try_append_connection(new_conn, from_block, is_input=False)
         self.__try_append_connection(new_conn, to_block, is_input=True)
 
         if not new_conn in self.connection_list:
+
             self.connection_list.append(new_conn)
             self.__reset_IDs(reset_block=False)
 
@@ -1651,13 +1679,12 @@ class ArrayHandler:
     # -- Elements Identification Methods --
     # -------------------------------------
 
-    def find_connection_by_index(self, index):
+    def find_connection_by_index(self, index: Union[float, int, str]) -> Union[Connection, None]:
 
+        index = float(index)
         for conn in self.connection_list:
-
             try:
-
-                if conn.index == index:
+                if float(conn.index) == index:
                     return conn
 
             except:
@@ -1776,22 +1803,6 @@ class ArrayHandler:
     # ------- Input/Output Methods --------
     # -------------------------------------
 
-    def append_excel_costs_and_useful_output(self, input_list, add_useful_output, input_cost):
-
-        for elem in input_list:
-
-            new_conn = self.find_connection_by_index(elem)
-
-            if not new_conn is None:
-
-                if add_useful_output:
-                    new_conn.is_useful_effect = True
-
-                else:
-                    new_conn.rel_cost = input_cost
-
-            # Overloaded Methods
-
     @property
     def xml(self) -> ETree.Element:
 
@@ -1876,6 +1887,13 @@ class ArrayHandler:
 
         return self.pf_diagram is not None
 
+    # -------------------------------------
+    # ----------- JSON Methods ------------
+    # -------------------------------------
+    def get_json_component_description(self) -> list:
+
+        return self.modules_handler.get_json_component_description()
+
     # -------------------------------------
     # ---- Elements Sequencing Methods ----
     # -------------------------------------
@@ -1903,11 +1921,12 @@ class ArrayHandler:
     def __update_block_list(self):
 
         # this method asks the blocks to generate their own support blocks (if needed) and appends them to the
-        # block list. Finally it orders the lists and reset the IDs.
+        # block list. Finally, it orders the lists and reset the IDs.
 
         for block in self.block_list:
 
             if block.has_support_block:
+
                 block_list = block.support_block
                 self.append_block(block_list)
 
@@ -1923,6 +1942,43 @@ class ArrayHandler:
         for block in self.block_list:
             block.move_skipped_block_at_the_end = False
 
+    def __get_empty_index(self):
+
+        i = 0
+        j = 0
+
+        while np.power(10, i) < self.n_connection:
+
+            i += 1
+
+        while self.find_connection_by_index(int(np.power(10, i)) + j) is not None:
+
+            j += 1
+
+        return int(np.power(10, i)) + j
+
+    @property
+    def blocks_by_index(self):
+
+        new_block_list = list()
+        for block in self.block_list:
+
+            inserted = False
+            for i in range(len(new_block_list)):
+
+                if new_block_list[i].index > block.index:
+
+                    new_block_list.insert(i, block)
+                    inserted = True
+                    break
+
+            if not inserted:
+
+                new_block_list.append(block)
+
+
+        return new_block_list
+
     def __str__(self):
 
         # enables printing and str() method
