@@ -1,4 +1,5 @@
 from EEETools.Tools.API.ExcelAPI.modules_importer import calculate_excel, import_excel_input, export_debug_info_to_excel
+from EEETools.Tools.API.Tools.sankey_diagram_generation import SankeyDiagramGenerator, SankeyDiagramOptions
 from EEETools.Tools.GUIElements.connection_and_block_check import CheckConnectionWidget
 from EEETools.Tools.GUIElements.net_plot_modules import display_network
 from EEETools.MainModules.main_module import CalculationOptions
@@ -76,9 +77,14 @@ def launch_network_display(excel_path=""):
     display_network(array_handler)
 
 
-def plot_sankey(excel_path="", show_component_mixers=False, generate_on_pf_diagram=True, display_costs=False):
+def plot_sankey(
+
+        excel_path="", show_component_mixers=False,
+        generate_on_pf_diagram=True, display_costs=False,
+        font_size=15, min_opacity_perc=0.15, change_opacity=True
+
+):
 
-    from EEETools.Tools.API.Tools.sankey_diagram_generation import SankeyDiagramGenerator, SankeyDiagramOptions
     excel_path = __find_excel_path(excel_path)
     if excel_path == "":
         return
@@ -89,6 +95,9 @@ def plot_sankey(excel_path="", show_component_mixers=False, generate_on_pf_diagr
     options.generate_on_pf_diagram = generate_on_pf_diagram
     options.show_component_mixers = show_component_mixers
     options.display_costs = display_costs
+    options.font_size = font_size
+    options.min_opacity_perc = min_opacity_perc
+    options.change_opacity = change_opacity
 
     SankeyDiagramGenerator(array_handler, options).show()
 
